==> axel_2.16.1.orig.tar.gz: axel-2.16.1/CONTRIBUTING.md <==
## HOW TO CONTRIBUTE TO AXEL DEVELOPMENT

Axel is available at https://github.com/axel-download-accelerator/axel

If you are interested in contribute to axel development, please, follow
these steps:

1. Send a patch that fix an issue or that implement a new feature.
   Alternatively, you can do a 'pull request'[1] in GitHub.

   [1] https://help.github.com/articles/using-pull-requests

2. Ask for join to the Axel project in GitHub, if you want to work
   officially. Note that this second step is not compulsory. However,
   to accept you in project, is needed a minimum previous collaboration.


To find issues and bugs to fix, you can check these addresses:

   - https://github.com/axel-download-accelerator/axel/issues
   - https://alioth.debian.org/tracker/?atid=413085&group_id=100070&func=browse
       (ALIOTH IS THE OLD HOMEPAGE, BUT HAS OPENED BUGS)
   - https://bugs.debian.org/cgi-bin/pkgreport.cgi?dist=unstable;package=axel
   - https://bugs.launchpad.net/ubuntu/+source/axel/+bugs
   - https://apps.fedoraproject.org/packages/axel/bugs
   - https://bugs.archlinux.org/?project=5&cat[]=33&string=axel
   - https://bugs.gentoo.org/buglist.cgi?quicksearch=net-misc%2Faxel

If you want to join, please make a contact.

There is a group here[2] to discuss and to coordinate the development.
You can also find other developers in the #axel channel on freenode.

[2] https://groups.google.com/forum/#!forum/axel-accelerator-dev

  -- Eriberto, Sun, 20 Mar 2016 16:27:53 -0300,
     updated on Sun, 08 Sep 2017 23:27:00 -0300.

==> axel_2.17.5.orig.tar.gz: axel-2.17.5/CONTRIBUTING.md <==
## HOW TO CONTRIBUTE TO AXEL DEVELOPMENT

Axel is available at https://github.com/axel-download-accelerator/axel

If you are interested in contribute to axel development, please, follow
these steps:

1. Send a patch that fix an issue or that implement a new feature.
   Alternatively, you can do a 'pull request'[1] in GitHub.

[1]: https://help.github.com/articles/using-pull-requests

2. Ask for join to the Axel project in GitHub, if you want to work
   officially. Note that this second step is not compulsory. However,
   to accept you in project, is needed a minimum previous collaboration.


To find issues and bugs to fix, you can check these addresses:

   - https://github.com/axel-download-accelerator/axel/issues
   - https://alioth.debian.org/tracker/?atid=413085&group_id=100070&func=browse
       (ALIOTH IS THE OLD HOMEPAGE, BUT HAS OPENED BUGS)
   - https://bugs.debian.org/cgi-bin/pkgreport.cgi?dist=unstable;package=axel
   - https://bugs.launchpad.net/ubuntu/+source/axel/+bugs
   - https://apps.fedoraproject.org/packages/axel/bugs
   - https://bugs.archlinux.org/?project=5&cat[]=33&string=axel
   - https://bugs.gentoo.org/buglist.cgi?quicksearch=net-misc%2Faxel

If you want to join, please make a contact.

There is a group here[2] to discuss and to coordinate the development.
You can also find other developers in the #axel channel on freenode.

[2]: https://groups.google.com/forum/#!forum/axel-accelerator-dev

  -- Eriberto, Sun, 20 Mar 2016 16:27:53 -0300,
     updated on Sun, 08 Sep 2017 23:27:00 -0300.
